# frozen_string_literal: true

module Hermes
  module Api
    module Dmo
      class HousingChannelsController < Hermes::Api::Dmo::ApplicationController
        before_action :authorize_administrator!
        set_instance_for %i[index show create update destroy]

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $eq
          $all
        ]

        ACCEPTABLE_PARAMS = %w[
          key
          label
          request_name
          code_ikos
          created_at
          updated_at
        ]

        MUTATE_PARAMS = %i[
          key
          label
          request_name
          code_ikos
        ]
        mutate_params_only *MUTATE_PARAMS

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end

        def authorize_administrator!
          return render_json_error(:unauthorized, :not_admin) unless current_user_roles.include?('Administrator')
        end
      end
    end
  end
end