module Hermes
  module Api
    module Dmo
      class RequiredDocumentsController < Hermes::Api::Dmo::ApplicationController

     

        MUTATE_PARAMS = %i[status metas]

        mutate_params_only(*MUTATE_PARAMS)

        def set_required_document
          @required_document = Hermes::RequiredDocument.find_by(id: params[:required_document_id])
        end

        def update
          return render_json_error(:unprocessable_entity, :not_allowed) unless can_update_required_documents?
          super
        end

        def create
          return render_json_error(:unprocessable_entity, :not_allowed)
        end

        def destroy
          return render_json_error(:unprocessable_entity, :not_allowed)
        end

        def historical_status
          if current_user_roles.include?('collaborateur offre logement')
            if (statuses=Hermes::Status.where(object_id: params['id'])).count > 0
              render json: {status: "success", code: 200, message: {'statuses' => statuses.order_by(created_at: :desc)}}
            else
              render json: {status: "no content", code: 204, message: {'statuses' => []}}
            end
          else
            render json: {status: "unauthorized", code: 401, message: "user is no collaborateur offre logement"}
          end
        end

   

        private

        def can_update_required_documents?
          current_user_roles.include?('collaborateur offre logement') ||
            current_user_roles.include?('superadministrateur')
        end
      end
    end
  end
end
